API docs for “spamfighter.core.message.test.test_serialize.TransitMessageTestCase”

# Class s.c.m.t.t.TransitMessageTestCase(unittest.TestCase):

Part of spamfighter.core.message.test.test_serialize View Source View In Hierarchy

Тест на `spamfighter.core.message.TransitMessage`.

Method | setUp | Undocumented
Method | testInterface | Undocumented
Method | testSerialize1 | Undocumented
Method | testSerialize2 | Undocumented
Method | testSerialize3 | Undocumented
Method | testSerialize4 | Undocumented
Method | testDeserialize | Undocumented

def setUp(self): (source)
Undocumented
def testInterface(self): (source)
Undocumented
def testSerialize1(self): (source)
Undocumented
def testSerialize2(self): (source)
Undocumented
def testSerialize3(self): (source)
Undocumented
def testSerialize4(self): (source)
Undocumented
def testDeserialize(self): (source)
Undocumented